[svn] commit: r3174 - in /branches/trac364: ./ src/bin/bind10/ src/bin/bindctl/ src/bin/cfgmgr/ src/bin/cmdctl/ src/bin/loadzone/ src/bin/msgq/ src/bin/tests/ src/bin/usermgr/ src/bin/xfrin/ src/bin/xfrout/ src/bin/zonemgr/ src/lib/python/isc/ src/lib/python/isc/Util/ src/lib/python/isc/util/ src/lib/python/isc/util/tests/ src/lib/python/isc/utils/

BIND 10 source code commits bind10-changes at lists.isc.org
Mon Oct 11 09:39:02 UTC 2010


Author: zhanglikun
Date: Mon Oct 11 09:39:02 2010
New Revision: 3174

Log:
Rename folder name from utils to util. 

Added:
    branches/trac364/src/lib/python/isc/util/
      - copied from r3142, branches/trac364/src/lib/python/isc/utils/
Removed:
    branches/trac364/src/lib/python/isc/Util/
    branches/trac364/src/lib/python/isc/utils/
Modified:
    branches/trac364/configure.ac
    branches/trac364/src/bin/bind10/bind10.py.in
    branches/trac364/src/bin/bindctl/bindctl-source.py.in
    branches/trac364/src/bin/cfgmgr/b10-cfgmgr.py.in
    branches/trac364/src/bin/cmdctl/cmdctl.py.in
    branches/trac364/src/bin/loadzone/b10-loadzone.py.in
    branches/trac364/src/bin/msgq/msgq.py.in
    branches/trac364/src/bin/tests/process_rename_test.py.in
    branches/trac364/src/bin/usermgr/b10-cmdctl-usermgr.py.in
    branches/trac364/src/bin/xfrin/xfrin.py.in
    branches/trac364/src/bin/xfrout/xfrout.py.in
    branches/trac364/src/bin/zonemgr/zonemgr.py.in
    branches/trac364/src/lib/python/isc/Makefile.am
    branches/trac364/src/lib/python/isc/util/Makefile.am
    branches/trac364/src/lib/python/isc/util/tests/process_test.py

Modified: branches/trac364/configure.ac
==============================================================================
--- branches/trac364/configure.ac (original)
+++ branches/trac364/configure.ac Mon Oct 11 09:39:02 2010
@@ -482,8 +482,8 @@
                  src/lib/cc/tests/Makefile
                  src/lib/python/Makefile
                  src/lib/python/isc/Makefile
-                 src/lib/python/isc/utils/Makefile
-                 src/lib/python/isc/utils/tests/Makefile
+                 src/lib/python/isc/util/Makefile
+                 src/lib/python/isc/util/tests/Makefile
                  src/lib/python/isc/datasrc/Makefile
                  src/lib/python/isc/cc/Makefile
                  src/lib/python/isc/cc/tests/Makefile

Modified: branches/trac364/src/bin/bind10/bind10.py.in
==============================================================================
--- branches/trac364/src/bin/bind10/bind10.py.in (original)
+++ branches/trac364/src/bin/bind10/bind10.py.in Mon Oct 11 09:39:02 2010
@@ -63,10 +63,10 @@
 import posix
 
 import isc.cc
-import isc.utils.process
+import isc.util.process
 
 # Assign this process some longer name
-isc.utils.process.rename(sys.argv[0])
+isc.util.process.rename(sys.argv[0])
 
 # This is the version that gets displayed to the user.
 # The VERSION string consists of the module name, the module version
@@ -627,7 +627,7 @@
 
 def process_rename(option, opt_str, value, parser):
     """Function that renames the process if it is requested by a option."""
-    isc.utils.process.rename(value)
+    isc.util.process.rename(value)
 
 def main():
     global options

Modified: branches/trac364/src/bin/bindctl/bindctl-source.py.in
==============================================================================
--- branches/trac364/src/bin/bindctl/bindctl-source.py.in (original)
+++ branches/trac364/src/bin/bindctl/bindctl-source.py.in Mon Oct 11 09:39:02 2010
@@ -24,9 +24,9 @@
 from bindctl.bindcmd import *
 import pprint
 from optparse import OptionParser, OptionValueError
-import isc.utils.process
+import isc.util.process
 
-isc.utils.process.rename()
+isc.util.process.rename()
 
 __version__ = 'Bindctl'
 

Modified: branches/trac364/src/bin/cfgmgr/b10-cfgmgr.py.in
==============================================================================
--- branches/trac364/src/bin/cfgmgr/b10-cfgmgr.py.in (original)
+++ branches/trac364/src/bin/cfgmgr/b10-cfgmgr.py.in Mon Oct 11 09:39:02 2010
@@ -21,11 +21,11 @@
 
 from isc.config.cfgmgr import ConfigManager, ConfigManagerDataReadError
 from isc.cc import SessionError
-import isc.utils.process
+import isc.util.process
 import signal
 import os
 
-isc.utils.process.rename()
+isc.util.process.rename()
 
 # If B10_FROM_SOURCE is set in the environment, we use data files
 # from a directory relative to that, otherwise we use the ones

Modified: branches/trac364/src/bin/cmdctl/cmdctl.py.in
==============================================================================
--- branches/trac364/src/bin/cmdctl/cmdctl.py.in (original)
+++ branches/trac364/src/bin/cmdctl/cmdctl.py.in Mon Oct 11 09:39:02 2010
@@ -42,7 +42,7 @@
 import time
 import signal
 from isc.config import ccsession
-import isc.utils.process
+import isc.util.process
 from optparse import OptionParser, OptionValueError
 from hashlib import sha1
 try:
@@ -50,7 +50,7 @@
 except ImportError:
     import dummy_threading as threading
 
-isc.utils.process.rename()
+isc.util.process.rename()
 
 __version__ = 'BIND10'
 URL_PATTERN = re.compile('/([\w]+)(?:/([\w]+))?/?')

Modified: branches/trac364/src/bin/loadzone/b10-loadzone.py.in
==============================================================================
--- branches/trac364/src/bin/loadzone/b10-loadzone.py.in (original)
+++ branches/trac364/src/bin/loadzone/b10-loadzone.py.in Mon Oct 11 09:39:02 2010
@@ -18,12 +18,12 @@
 import sys; sys.path.append ('@@PYTHONPATH@@')
 import re, getopt
 import isc.datasrc
-import isc.utils.process
+import isc.util.process
 from isc.datasrc.master import MasterFile
 import time
 import os
 
-isc.utils.process.rename()
+isc.util.process.rename()
 
 #########################################################################
 # usage: print usage note and exit

Modified: branches/trac364/src/bin/msgq/msgq.py.in
==============================================================================
--- branches/trac364/src/bin/msgq/msgq.py.in (original)
+++ branches/trac364/src/bin/msgq/msgq.py.in Mon Oct 11 09:39:02 2010
@@ -31,11 +31,11 @@
 import pprint
 import random
 from optparse import OptionParser, OptionValueError
-import isc.utils.process
+import isc.util.process
 
 import isc.cc
 
-isc.utils.process.rename()
+isc.util.process.rename()
 
 # This is the version that gets displayed to the user.
 __version__ = "v20091030 (Paving the DNS Parking Lot)"

Modified: branches/trac364/src/bin/tests/process_rename_test.py.in
==============================================================================
--- branches/trac364/src/bin/tests/process_rename_test.py.in (original)
+++ branches/trac364/src/bin/tests/process_rename_test.py.in Mon Oct 11 09:39:02 2010
@@ -17,7 +17,7 @@
 import unittest
 import os
 import os.path
-import isc.utils.process
+import isc.util.process
 import re
 
 class TestRename(unittest.TestCase):
@@ -28,7 +28,7 @@
         data = ''.join(open(filename).readlines())
         prettyname = 'src' + filename[filename.rfind('../') + 2:]
         self.assertTrue(fun.search(data),
-            "Didn't find a call to isc.utils.process.rename in " + prettyname)
+            "Didn't find a call to isc.util.process.rename in " + prettyname)
 
     def test_calls(self):
         """
@@ -45,7 +45,7 @@
         # Script name regular expression
         scripts = re.compile(r'((\w|[-.0-9])+)')
         # Line with the call
-        fun = re.compile(r'^\s*isc\.utils\.process\.rename\s*\(.*\)\s*(|#.*)$',
+        fun = re.compile(r'^\s*isc\.util\.process\.rename\s*\(.*\)\s*(|#.*)$',
             re.MULTILINE)
 
         # Find all Makefile and extract names of scripts

Modified: branches/trac364/src/bin/usermgr/b10-cmdctl-usermgr.py.in
==============================================================================
--- branches/trac364/src/bin/usermgr/b10-cmdctl-usermgr.py.in (original)
+++ branches/trac364/src/bin/usermgr/b10-cmdctl-usermgr.py.in Mon Oct 11 09:39:02 2010
@@ -25,9 +25,9 @@
 import getpass
 import getopt
 import sys
-import isc.utils.process
+import isc.util.process
 
-isc.utils.process.rename()
+isc.util.process.rename()
 
 VERSION_NUMBER = 'bind10'
 DEFAULT_FILE = 'cmdctl-accounts.csv'

Modified: branches/trac364/src/bin/xfrin/xfrin.py.in
==============================================================================
--- branches/trac364/src/bin/xfrin/xfrin.py.in (original)
+++ branches/trac364/src/bin/xfrin/xfrin.py.in Mon Oct 11 09:39:02 2010
@@ -29,7 +29,7 @@
 from optparse import OptionParser, OptionValueError
 from isc.config.ccsession import *
 from isc.notify import notify_out
-import isc.utils.process
+import isc.util.process
 try:
     from pydnspp import *
 except ImportError as e:
@@ -37,7 +37,7 @@
     # must keep running, so we warn about it and move forward.
     sys.stderr.write('[b10-xfrin] failed to import DNS module: %s\n' % str(e))
 
-isc.utils.process.rename()
+isc.util.process.rename()
 
 # If B10_FROM_BUILD is set in the environment, we use data files
 # from a directory relative to that, otherwise we use the ones

Modified: branches/trac364/src/bin/xfrout/xfrout.py.in
==============================================================================
--- branches/trac364/src/bin/xfrout/xfrout.py.in (original)
+++ branches/trac364/src/bin/xfrout/xfrout.py.in Mon Oct 11 09:39:02 2010
@@ -29,7 +29,7 @@
 from isc.log.log import *
 from isc.cc import SessionError, SessionTimeout
 from isc.notify import notify_out
-import isc.utils.process
+import isc.util.process
 import socket
 import select
 import errno
@@ -42,7 +42,7 @@
     # must keep running, so we warn about it and move forward.
     sys.stderr.write('[b10-xfrout] failed to import DNS or XFR module: %s\n' % str(e))
 
-isc.utils.process.rename()
+isc.util.process.rename()
 
 if "B10_FROM_BUILD" in os.environ:
     SPECFILE_PATH = os.environ["B10_FROM_BUILD"] + "/src/bin/xfrout"

Modified: branches/trac364/src/bin/zonemgr/zonemgr.py.in
==============================================================================
--- branches/trac364/src/bin/zonemgr/zonemgr.py.in (original)
+++ branches/trac364/src/bin/zonemgr/zonemgr.py.in Mon Oct 11 09:39:02 2010
@@ -36,9 +36,9 @@
 from isc.datasrc import sqlite3_ds
 from optparse import OptionParser, OptionValueError
 from isc.config.ccsession import *
-import isc.utils.process
-
-isc.utils.process.rename()
+import isc.util.process
+
+isc.util.process.rename()
 
 # If B10_FROM_BUILD is set in the environment, we use data files
 # from a directory relative to that, otherwise we use the ones

Modified: branches/trac364/src/lib/python/isc/Makefile.am
==============================================================================
--- branches/trac364/src/lib/python/isc/Makefile.am (original)
+++ branches/trac364/src/lib/python/isc/Makefile.am Mon Oct 11 09:39:02 2010
@@ -1,4 +1,4 @@
-SUBDIRS = datasrc cc config log notify utils # Util
+SUBDIRS = datasrc cc config log notify util 
 
 python_PYTHON = __init__.py
 

Modified: branches/trac364/src/lib/python/isc/util/Makefile.am
==============================================================================
--- branches/trac364/src/lib/python/isc/util/Makefile.am (original)
+++ branches/trac364/src/lib/python/isc/util/Makefile.am Mon Oct 11 09:39:02 2010
@@ -2,4 +2,4 @@
 
 python_PYTHON = __init__.py process.py
 
-pythondir = $(pyexecdir)/isc/utils
+pythondir = $(pyexecdir)/isc/util

Modified: branches/trac364/src/lib/python/isc/util/tests/process_test.py
==============================================================================
--- branches/trac364/src/lib/python/isc/util/tests/process_test.py (original)
+++ branches/trac364/src/lib/python/isc/util/tests/process_test.py Mon Oct 11 09:39:02 2010
@@ -13,9 +13,9 @@
 # NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
 # WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 
 """Tests for isc.utils.process."""
 import unittest
-import isc.utils.process
+import isc.util.process
 run_tests = True
 try:
     import setproctitle
@@ -30,9 +30,9 @@
     @unittest.skipIf(not run_tests, "Setproctitle not installed, not testing")
     def test_rename(self):
         """Test if the renaming function works."""
-        isc.utils.process.rename("rename-test")
+        isc.util.process.rename("rename-test")
         self.assertEqual("rename-test", self.__get_self_name())
-        isc.utils.process.rename()
+        isc.util.process.rename()
         self.assertEqual("process_test.py", self.__get_self_name())
 
 if __name__ == "__main__":
@@ -13,9 +13,9 @@
 # WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 
-"""Tests for isc.utils.process."""
+"""Tests for isc.util.process."""
 import unittest




More information about the bind10-changes mailing list